@@ -18,9 +18,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include <gtk/gtk.h>
 
@@ -37,7 +35,6 @@
 typedef struct _BluetoothPairingDialogPrivate BluetoothPairingDialogPrivate;
 
 struct _BluetoothPairingDialogPrivate {
-	GtkWidget            *title;
 	GtkWidget            *help_label;
 	GtkWidget            *label_pin;
 	GtkWidget            *entry_pin;
@@ -50,7 +47,7 @@ struct _BluetoothPairingDialogPrivate {
 	char                 *pin;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE(BluetoothPairingDialog, bluetooth_pairing_dialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE_WITH_PRIVATE(BluetoothPairingDialog, bluetooth_pairing_dialog, ADW_TYPE_DIALOG)
 
 enum {
 	CONFIRMATION_PAGE,
@@ -58,6 +55,13 @@ enum {
 	MESSAGE_PAGE
 };
 
+enum {
+  RESPONSE,
+  LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL];
+
 void
 bluetooth_pairing_dialog_set_mode (BluetoothPairingDialog *self,
 				   BluetoothPairingMode    mode,
@@ -67,24 +71,24 @@ bluetooth_pairing_dialog_set_mode (BluetoothPairingDialog *self,
 	BluetoothPairingDialogPrivate *priv = BLUETOOTH_PAIRING_DIALOG_GET_PRIVATE (self);
 	g_autofree char *title = NULL;
 	g_autofree char *help = NULL;
-	GtkStyleContext *context;
 
 	priv->mode = mode;
 
 	g_clear_pointer (&priv->pin, g_free);
 	priv->pin = g_strdup (pin);
-	gtk_entry_set_text (GTK_ENTRY (priv->entry_pin), pin ? pin : "");
+	gtk_editable_set_text (GTK_EDITABLE (priv->entry_pin), pin ? pin : "");
+	gtk_entry_set_visibility (GTK_ENTRY (priv->entry_pin), TRUE);
 	gtk_label_set_text (GTK_LABEL (priv->label_pin), pin);
 
 	switch (mode) {
 	case BLUETOOTH_PAIRING_MODE_PIN_QUERY:
-		gtk_widget_show (priv->done);
+		gtk_widget_set_visible (priv->done, TRUE);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->pin_notebook), CONFIRMATION_PAGE);
 		title = g_strdup(_("Confirm Bluetooth PIN"));
 		help = g_strdup_printf (_("Please confirm the PIN that was entered on “%s”."), device_name);
 		break;
 	case BLUETOOTH_PAIRING_MODE_PIN_CONFIRMATION:
-		gtk_widget_show (priv->done);
+		gtk_widget_set_visible (priv->done, TRUE);
 		gtk_button_set_label (GTK_BUTTON (priv->done), _("Confirm"));
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->pin_notebook), CONFIRMATION_PAGE);
 		title = g_strdup(_("Confirm Bluetooth PIN"));
@@ -93,25 +97,25 @@ bluetooth_pairing_dialog_set_mode (BluetoothPairingDialog *self,
 	case BLUETOOTH_PAIRING_MODE_PIN_DISPLAY_NORMAL:
 	case BLUETOOTH_PAIRING_MODE_PIN_DISPLAY_KEYBOARD:
 	case BLUETOOTH_PAIRING_MODE_PIN_DISPLAY_ICADE:
-		gtk_widget_hide (priv->done);
+		gtk_widget_set_visible (priv->done, FALSE);
 		title = g_strdup_printf (_("Pairing “%s”"), device_name);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->pin_notebook), DISPLAY_PAGE);
 		break;
 	case BLUETOOTH_PAIRING_MODE_PIN_MATCH:
 		gtk_button_set_label (GTK_BUTTON (priv->done), _("Confirm"));
-		gtk_widget_show (priv->done);
+		gtk_widget_set_visible (priv->done, TRUE);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->pin_notebook), DISPLAY_PAGE);
 		title = g_strdup(_("Confirm Bluetooth PIN"));
 		help = g_strdup_printf (_("Please confirm that the following PIN matches the one displayed on “%s”."), device_name);
 		break;
 	case BLUETOOTH_PAIRING_MODE_YES_NO:
-		gtk_widget_show (priv->done);
+		gtk_widget_set_visible (priv->done, TRUE);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->pin_notebook), MESSAGE_PAGE);
 		title = g_strdup (_("Bluetooth Pairing Request"));
 		help = g_strdup_printf (_("“%s” wants to pair with this device. Do you want to allow pairing?"), device_name);
 		break;
 	case BLUETOOTH_PAIRING_MODE_CONFIRM_AUTH:
-		gtk_widget_show (priv->done);
+		gtk_widget_set_visible (priv->done, TRUE);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->pin_notebook), MESSAGE_PAGE);
 		title = g_strdup (_("Confirm Bluetooth Connection"));
 		help = g_strdup_printf (_("“%s” wants to connect with this device. Do you want to allow it?"), device_name);
@@ -126,6 +130,8 @@ bluetooth_pairing_dialog_set_mode (BluetoothPairingDialog *self,
 		break;
 	case BLUETOOTH_PAIRING_MODE_PIN_DISPLAY_KEYBOARD:
 		help = g_strdup_printf (_("Please enter the following PIN on “%s”. Then press “Return” on the keyboard."), device_name);
+		/* populate the invisible character */
+		gtk_entry_set_visibility (GTK_ENTRY (priv->entry_pin), FALSE);
 		break;
 	case BLUETOOTH_PAIRING_MODE_PIN_DISPLAY_ICADE:
 		help = g_strdup (_("Please move the joystick of your iCade in the following directions. Then press any of the white buttons."));
@@ -137,27 +143,23 @@ bluetooth_pairing_dialog_set_mode (BluetoothPairingDialog *self,
 	if (mode == BLUETOOTH_PAIRING_MODE_YES_NO ||
 	    mode == BLUETOOTH_PAIRING_MODE_CONFIRM_AUTH) {
 		gtk_button_set_label (GTK_BUTTON (priv->done), _("Allow"));
-		context = gtk_widget_get_style_context (priv->done);
-		gtk_style_context_remove_class (context, "suggested-action");
+		gtk_widget_remove_css_class (priv->done, "suggested-action");
 
 		gtk_button_set_label (GTK_BUTTON (priv->cancel), _("Dismiss"));
-		context = gtk_widget_get_style_context (priv->cancel);
-		gtk_style_context_add_class (context, "destructive-action");
+		gtk_widget_add_css_class (priv->cancel, "destructive-action");
 
-		gtk_widget_hide (priv->pin_notebook);
+		gtk_widget_set_visible (priv->pin_notebook, FALSE);
 	} else {
 		gtk_button_set_label (GTK_BUTTON (priv->done), _("Confirm"));
-		context = gtk_widget_get_style_context (priv->done);
-		gtk_style_context_add_class (context, "suggested-action");
+		gtk_widget_add_css_class (priv->done, "suggested-action");
 
 		gtk_button_set_label (GTK_BUTTON (priv->cancel), _("Cancel"));
-		context = gtk_widget_get_style_context (priv->cancel);
-		gtk_style_context_remove_class (context, "destructive-action");
+		gtk_widget_remove_css_class (priv->cancel, "destructive-action");
 
-		gtk_widget_show (priv->pin_notebook);
+		gtk_widget_set_visible (priv->pin_notebook, TRUE);
 	}
 
-	gtk_label_set_text (GTK_LABEL (priv->title), title);
+	adw_dialog_set_title (ADW_DIALOG (self), title);
 	gtk_label_set_text (GTK_LABEL (priv->help_label), help);
 }
 
@@ -178,7 +180,7 @@ bluetooth_pairing_dialog_get_pin (BluetoothPairingDialog *self)
 		  priv->mode == BLUETOOTH_PAIRING_MODE_PIN_QUERY);
 	g_assert (gtk_widget_is_sensitive (GTK_WIDGET (priv->done)));
 
-	return g_strdup (gtk_entry_get_text (GTK_ENTRY (priv->entry_pin)));
+	return g_strdup (gtk_editable_get_text (GTK_EDITABLE (priv->entry_pin)));
 }
 
 void
@@ -186,7 +188,7 @@ bluetooth_pairing_dialog_set_pin_entered (BluetoothPairingDialog *self,
 					  guint                   entered)
 {
 	BluetoothPairingDialogPrivate *priv = BLUETOOTH_PAIRING_DIALOG_GET_PRIVATE (self);
-	char *done;
+	g_autofree char *done = NULL;
 
 	g_assert (priv->mode == BLUETOOTH_PAIRING_MODE_PIN_DISPLAY_KEYBOARD);
 	g_assert (priv->pin);
@@ -197,6 +199,8 @@ bluetooth_pairing_dialog_set_pin_entered (BluetoothPairingDialog *self,
 		guint i;
 
 		invisible = gtk_entry_get_invisible_char (GTK_ENTRY (priv->entry_pin));
+		if (invisible == 0)
+			invisible = '*';
 
 		str = g_string_new (NULL);
 		for (i = 0; i < entered; i++)
@@ -210,14 +214,14 @@ bluetooth_pairing_dialog_set_pin_entered (BluetoothPairingDialog *self,
 	}
 
 	gtk_label_set_text (GTK_LABEL (priv->label_pin), done);
-	g_free (done);
 }
 
 static void
 response_cb (GtkWidget *button,
 	     gpointer   user_data)
 {
-	BluetoothPairingDialogPrivate *priv = BLUETOOTH_PAIRING_DIALOG_GET_PRIVATE (user_data);
+	BluetoothPairingDialog *self = user_data;
+	BluetoothPairingDialogPrivate *priv = BLUETOOTH_PAIRING_DIALOG_GET_PRIVATE (self);
 	int response;
 
 	if (button == priv->done)
@@ -227,7 +231,14 @@ response_cb (GtkWidget *button,
 	else
 		g_assert_not_reached ();
 
-	gtk_dialog_response (GTK_DIALOG (user_data), response);
+	adw_dialog_set_can_close (ADW_DIALOG (self), TRUE);
+	g_signal_emit (self, signals[RESPONSE], 0, response);
+}
+
+static void
+close_attempt_cb (AdwDialog *dialog)
+{
+	g_signal_emit (dialog, signals[RESPONSE], 0, GTK_RESPONSE_DELETE_EVENT);
 }
 
 static void
@@ -242,7 +253,7 @@ text_changed_cb (GObject    *gobject,
 	    priv->mode != BLUETOOTH_PAIRING_MODE_PIN_QUERY)
 		return;
 
-	text = gtk_entry_get_text (GTK_ENTRY (priv->entry_pin));
+	text = gtk_editable_get_text (GTK_EDITABLE (priv->entry_pin));
 	if (!text || strlen (text) < 4)
 		gtk_widget_set_sensitive (GTK_WIDGET (priv->done), FALSE);
 	else
@@ -252,20 +263,15 @@ text_changed_cb (GObject    *gobject,
 static void
 bluetooth_pairing_dialog_init (BluetoothPairingDialog *self)
 {
-	GtkCssProvider *provider;
+	g_autoptr(GtkCssProvider) provider = NULL;
 
 	gtk_widget_init_template (GTK_WIDGET (self));
 
-	gtk_widget_set_size_request (GTK_WIDGET (self), 380, -1);
-	gtk_window_set_resizable (GTK_WINDOW (self), FALSE);
-
 	provider = gtk_css_provider_new ();
 	gtk_css_provider_load_from_resource (provider, "/org/gnome/bluetooth/bluetooth-settings.css");
-	gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-						   GTK_STYLE_PROVIDER (provider),
-						   GTK_STYLE_PROVIDER_PRIORITY_USER);
-	g_object_unref (provider);
-
+	gtk_style_context_add_provider_for_display (gdk_display_get_default (),
+						    GTK_STYLE_PROVIDER (provider),
+						    GTK_STYLE_PROVIDER_PRIORITY_USER);
 }
 
 static void
@@ -273,50 +279,13 @@ bluetooth_pairing_dialog_constructed (GObject *object)
 {
 	BluetoothPairingDialog *self = BLUETOOTH_PAIRING_DIALOG (object);
 	BluetoothPairingDialogPrivate *priv = BLUETOOTH_PAIRING_DIALOG_GET_PRIVATE (self);
-	GtkWidget *header;
-	GtkStyleContext *context;
 
-	/* Header */
-	header = gtk_dialog_get_header_bar (GTK_DIALOG (self));
-	priv->title = gtk_label_new ("");
-	gtk_header_bar_set_custom_title (GTK_HEADER_BAR (header), priv->title);
-	gtk_widget_show (priv->title);
-	gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (header), FALSE);
-
-	/* OK button */
-	priv->done = gtk_button_new_with_label (_("Accept"));
-	gtk_widget_set_no_show_all (priv->done, TRUE);
-	gtk_widget_set_can_default (GTK_WIDGET (priv->done), TRUE);
-	g_signal_connect (G_OBJECT (priv->done), "clicked",
-			  G_CALLBACK (response_cb), self);
-	gtk_header_bar_pack_end (GTK_HEADER_BAR (header), priv->done);
-
-	/* Spinner */
-	priv->spinner = gtk_spinner_new ();
-	gtk_widget_set_margin_end (priv->spinner, 12);
-	gtk_widget_set_no_show_all (priv->spinner, TRUE);
-	gtk_header_bar_pack_end (GTK_HEADER_BAR (header), priv->spinner);
-	g_object_bind_property (priv->spinner, "visible",
-				priv->spinner, "active", 0);
-	g_object_bind_property (priv->spinner, "visible",
-				priv->done, "visible",
-				G_BINDING_SYNC_CREATE | G_BINDING_INVERT_BOOLEAN | G_BINDING_BIDIRECTIONAL);
-
-	/* Cancel button */
-	priv->cancel = gtk_button_new_with_label (_("Cancel"));
-	g_signal_connect (G_OBJECT (priv->cancel), "clicked",
-			  G_CALLBACK (response_cb), self);
-	gtk_header_bar_pack_start (GTK_HEADER_BAR (header), priv->cancel);
-	gtk_widget_show (priv->cancel);
-	gtk_widget_grab_default (GTK_WIDGET (priv->done));
+	G_OBJECT_CLASS(bluetooth_pairing_dialog_parent_class)->constructed (object);
 
 	g_signal_connect (G_OBJECT (priv->entry_pin), "notify::text",
 			  G_CALLBACK (text_changed_cb), self);
 
-	context = gtk_widget_get_style_context (priv->done);
-	gtk_style_context_add_class (context, "suggested-action");
-	context = gtk_widget_get_style_context (priv->title);
-	gtk_style_context_add_class (context, "title");
+	gtk_widget_add_css_class (priv->done, "suggested-action");
 }
 
 static void
@@ -340,12 +309,26 @@ bluetooth_pairing_dialog_class_init (BluetoothPairingDialogClass *klass)
 	object_class->constructed = bluetooth_pairing_dialog_constructed;
 	object_class->finalize = bluetooth_pairing_dialog_finalize;
 
+	signals[RESPONSE] = g_signal_new ("response",
+					  G_OBJECT_CLASS_TYPE (klass),
+					  G_SIGNAL_RUN_LAST,
+					  0,
+					  NULL, NULL,
+					  NULL,
+					  G_TYPE_NONE, 1,
+					  G_TYPE_INT);
+
 	/* Bind class to template */
 	gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/bluetooth/bluetooth-pairing-dialog.ui");
 	gtk_widget_class_bind_template_child_private (widget_class, BluetoothPairingDialog, help_label);
 	gtk_widget_class_bind_template_child_private (widget_class, BluetoothPairingDialog, pin_notebook);
 	gtk_widget_class_bind_template_child_private (widget_class, BluetoothPairingDialog, entry_pin);
 	gtk_widget_class_bind_template_child_private (widget_class, BluetoothPairingDialog, label_pin);
+	gtk_widget_class_bind_template_child_private (widget_class, BluetoothPairingDialog, done);
+	gtk_widget_class_bind_template_child_private (widget_class, BluetoothPairingDialog, spinner);
+	gtk_widget_class_bind_template_child_private (widget_class, BluetoothPairingDialog, cancel);
+	gtk_widget_class_bind_template_callback (widget_class, response_cb);
+	gtk_widget_class_bind_template_callback (widget_class, close_attempt_cb);
 }
 
 /**
@@ -358,7 +341,5 @@ bluetooth_pairing_dialog_class_init (BluetoothPairingDialogClass *klass)
 GtkWidget *
 bluetooth_pairing_dialog_new (void)
 {
-	return g_object_new (BLUETOOTH_TYPE_PAIRING_DIALOG,
-	                     "use-header-bar", 1,
-	                     NULL);
+	return g_object_new (BLUETOOTH_TYPE_PAIRING_DIALOG, NULL);
 }
