@@ -49,20 +49,20 @@ struct _BluetoothSettingsWidget {
 
 	/* Pairing */
 	BluetoothAgent      *agent;
-	GtkWindow           *pairing_dialog;
+	AdwDialog           *pairing_dialog;
 	GHashTable          *pairing_devices; /* key=object-path, value=boolean */
 
 	/* Properties */
-	GtkWindow           *properties_dialog;
+	AdwDialog           *properties_dialog;
 	char                *selected_bdaddr;
 	char                *selected_name;
 	char                *selected_object_path;
 
 	/* Device section */
+        GtkWidget           *page;
 	GtkWidget           *device_list;
 	GtkAdjustment       *focus_adjustment;
 	GtkSizeGroup        *row_sizegroup;
-	GtkWidget           *device_stack;
 	GtkWidget           *device_spinner;
 	GHashTable          *connecting_devices; /* key=bdaddr, value=boolean */
 
@@ -71,7 +71,6 @@ struct _BluetoothSettingsWidget {
 	GHashTable          *devices_type; /* key=bdaddr, value=guint32 */
 
 	/* Sharing section */
-	GtkWidget           *explanation_group;
 	gboolean             has_console;
 	GDBusProxy          *session_proxy;
 };
@@ -105,9 +104,6 @@ static guint signals[LAST_SIGNAL] = { 0 };
 #define GNOME_SESSION_DBUS_OBJECT    "/org/gnome/SessionManager"
 #define GNOME_SESSION_DBUS_INTERFACE "org.gnome.SessionManager"
 
-#define FILLER_PAGE                  "filler-page"
-#define DEVICES_PAGE                 "devices-page"
-
 enum {
 	CONNECTING_STATE_IDLE = 0,
 	CONNECTING_STATE_LOADING = 1
@@ -118,11 +114,9 @@ set_connecting_state (BluetoothSettingsWidget *self,
 		     int                      state)
 {
 	if (state == CONNECTING_STATE_LOADING) {
-		gtk_spinner_start (GTK_SPINNER (WID ("connecting_spinner")));
 		gtk_widget_set_visible (GTK_WIDGET (WID ("connecting_spinner")), TRUE);
 		gtk_widget_set_sensitive (GTK_WIDGET (WID ("switch_connection")), FALSE);
 	} else {
-		gtk_spinner_stop (GTK_SPINNER (WID ("connecting_spinner")));
 		gtk_widget_set_visible (GTK_WIDGET (WID ("connecting_spinner")), FALSE);
 		gtk_widget_set_sensitive (GTK_WIDGET (WID ("switch_connection")), TRUE);
 	}
@@ -231,13 +225,8 @@ add_device_type (BluetoothSettingsWidget *self,
 static void
 setup_pairing_dialog (BluetoothSettingsWidget *self)
 {
-	GtkWidget *toplevel;
-
-	g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
-	self->pairing_dialog = GTK_WINDOW (bluetooth_pairing_dialog_new ());
-	toplevel = GTK_WIDGET (gtk_widget_get_native (GTK_WIDGET (self)));
-	gtk_window_set_transient_for (self->pairing_dialog, GTK_WINDOW (toplevel));
-	gtk_window_set_modal (self->pairing_dialog, TRUE);
+	g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
+	self->pairing_dialog = ADW_DIALOG (bluetooth_pairing_dialog_new ());
 }
 
 static gboolean
@@ -324,17 +313,17 @@ get_icade_pincode (char **pin_display_str)
 }
 
 static void
-display_cb (GtkDialog *dialog,
+display_cb (AdwDialog *dialog,
 	    int        response,
 	    gpointer   user_data)
 {
 	BluetoothSettingsWidget *self = user_data;
 
-	g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
+	g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
 }
 
 static void
-enter_pin_cb (GtkDialog *dialog,
+enter_pin_cb (AdwDialog *dialog,
 	      int        response,
 	      gpointer   user_data)
 {
@@ -355,7 +344,7 @@ enter_pin_cb (GtkDialog *dialog,
 						       g_variant_new ("(s)", pin));
 
 		if (bluetooth_pairing_dialog_get_mode (BLUETOOTH_PAIRING_DIALOG (self->pairing_dialog)) == BLUETOOTH_PAIRING_MODE_PIN_QUERY) {
-			g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
+			g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
 			return;
 		}
 		bluetooth_pairing_dialog_set_mode (BLUETOOTH_PAIRING_DIALOG (self->pairing_dialog),
@@ -366,7 +355,7 @@ enter_pin_cb (GtkDialog *dialog,
 		g_dbus_method_invocation_return_dbus_error (invocation,
 							    "org.bluez.Error.Canceled",
 							    "User cancelled pairing");
-		g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
+		g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
 		return;
 	}
 
@@ -376,7 +365,7 @@ enter_pin_cb (GtkDialog *dialog,
 }
 
 static void
-confirm_remote_pin_cb (GtkDialog *dialog,
+confirm_remote_pin_cb (AdwDialog *dialog,
 		       int        response,
 		       gpointer   user_data)
 {
@@ -400,7 +389,7 @@ confirm_remote_pin_cb (GtkDialog *dialog,
 		g_dbus_method_invocation_return_dbus_error (invocation, "org.bluez.Error.Rejected", "Pairing refused from settings panel");
 	}
 
-	g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
+	g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
 }
 
 static void
@@ -494,7 +483,7 @@ pincode_callback (GDBusMethodInvocation *invocation,
 				  G_CALLBACK (confirm_remote_pin_cb), user_data);
 	}
 
-	gtk_window_present (self->pairing_dialog);
+	adw_dialog_present (self->pairing_dialog, GTK_WIDGET (self));
 }
 
 static void
@@ -515,7 +504,7 @@ cancel_setup_cb (GObject      *source_object,
 }
 
 static void
-display_passkey_or_pincode_cb (GtkDialog *dialog,
+display_passkey_or_pincode_cb (AdwDialog *dialog,
 			       int        response,
 			       gpointer   user_data)
 {
@@ -535,7 +524,7 @@ display_passkey_or_pincode_cb (GtkDialog *dialog,
 		g_assert_not_reached ();
 	}
 
-	g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
+	g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
 }
 
 static void
@@ -569,7 +558,7 @@ display_passkey_callback (GDBusMethodInvocation *invocation,
 				"path", g_strdup (g_dbus_proxy_get_object_path (device)),
 				g_free);
 
-	gtk_window_present (self->pairing_dialog);
+	adw_dialog_present (self->pairing_dialog, GTK_WIDGET (self));
 }
 
 static void
@@ -633,7 +622,7 @@ display_pincode_callback (GDBusMethodInvocation *invocation,
 	g_object_set_data_full (G_OBJECT (self->pairing_dialog),
 				"path", g_strdup (g_dbus_proxy_get_object_path (device)),
 				g_free);
-	gtk_window_present (self->pairing_dialog);
+	adw_dialog_present (self->pairing_dialog, GTK_WIDGET (self));
 
 	g_dbus_method_invocation_return_value (invocation, NULL);
 }
@@ -658,11 +647,12 @@ cancel_callback (GDBusMethodInvocation *invocation,
 
 	g_debug ("cancel_callback ()");
 
-	g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
+	g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
 
 	child = gtk_widget_get_first_child (self->device_list);
 	while (child) {
-		g_object_set (G_OBJECT (child), "pairing", FALSE, NULL);
+		if (GTK_IS_LIST_BOX_ROW (child))
+			g_object_set (G_OBJECT (child), "pairing", FALSE, NULL);
 		child = gtk_widget_get_next_sibling (child);
 	}
 
@@ -672,7 +662,7 @@ cancel_callback (GDBusMethodInvocation *invocation,
 }
 
 static void
-confirm_cb (GtkDialog *dialog,
+confirm_cb (AdwDialog *dialog,
 	    int        response,
 	    gpointer   user_data)
 {
@@ -687,7 +677,7 @@ confirm_cb (GtkDialog *dialog,
 							    "org.bluez.Error.Canceled",
 							    "User cancelled pairing");
 	}
-	g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
+	g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
 }
 
 static void
@@ -714,7 +704,7 @@ confirm_callback (GDBusMethodInvocation *invocation,
 			  G_CALLBACK (confirm_cb), user_data);
 	g_object_set_data (G_OBJECT (self->pairing_dialog), "invocation", invocation);
 
-	gtk_window_present (self->pairing_dialog);
+	adw_dialog_present (self->pairing_dialog, GTK_WIDGET (self));
 }
 
 static void
@@ -737,11 +727,11 @@ authorize_callback (GDBusMethodInvocation *invocation,
 			  G_CALLBACK (confirm_cb), user_data);
 	g_object_set_data (G_OBJECT (self->pairing_dialog), "invocation", invocation);
 
-	gtk_window_present (self->pairing_dialog);
+	adw_dialog_present (self->pairing_dialog, GTK_WIDGET (self));
 }
 
 static void
-authorize_service_cb (GtkDialog *dialog,
+authorize_service_cb (AdwDialog *dialog,
 		      int        response,
 		      gpointer   user_data)
 {
@@ -762,7 +752,7 @@ authorize_service_cb (GtkDialog *dialog,
 		msg = g_strdup_printf ("Rejecting service auth (HID): not paired or trusted");
 		g_dbus_method_invocation_return_dbus_error (invocation, "org.bluez.Error.Rejected", msg);
 	}
-	g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
+	g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
 }
 
 static void
@@ -820,7 +810,7 @@ authorize_service_callback (GDBusMethodInvocation *invocation,
 		g_object_set_data_full (G_OBJECT (invocation), "device", g_object_ref (device), g_object_unref);
 		g_object_set_data (G_OBJECT (self->pairing_dialog), "invocation", invocation);
 
-		gtk_window_present (self->pairing_dialog);
+		adw_dialog_present (self->pairing_dialog, GTK_WIDGET (self));
 	}
 }
 
@@ -931,7 +921,7 @@ create_callback (GObject      *source_object,
 		if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
 			return;
 
-		g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
+		g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
 
 		turn_off_pairing (user_data, path);
 
@@ -960,7 +950,7 @@ create_callback (GObject      *source_object,
 		return;
 	}
 
-	g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
+	g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
 
 	g_hash_table_remove (self->pairing_devices, path);
 
@@ -1119,18 +1109,21 @@ update_properties (BluetoothSettingsWidget *self,
 	self->selected_object_path = g_strdup (bluetooth_device_get_object_path (device));
 
 	/* Hide all the buttons now, and show them again if we need to */
-	gtk_widget_set_visible (WID ("keyboard_button"), FALSE);
-	gtk_widget_set_visible (WID ("sound_button"), FALSE);
-	gtk_widget_set_visible (WID ("mouse_button"), FALSE);
-	gtk_widget_set_visible (WID ("send_button"), FALSE);
+	gtk_widget_set_visible (WID ("keyboard_button_row"), FALSE);
+	gtk_widget_set_visible (WID ("sound_button_row"), FALSE);
+	gtk_widget_set_visible (WID ("mouse_button_row"), FALSE);
+	gtk_widget_set_visible (WID ("send_button_row"), FALSE);
+
+        /* Properties dialog title */
+        adw_dialog_set_title (ADW_DIALOG (WID ("properties_dialog")), alias);
 
 	/* Name */
-	adw_status_page_set_title (ADW_STATUS_PAGE (WID ("status_page")), alias);
+        gtk_label_set_label (GTK_LABEL (WID ("device_name")), alias);
 	g_free (self->selected_name);
 	self->selected_name = alias;
 
 	/* Icon */
-	adw_status_page_set_icon_name (ADW_STATUS_PAGE (WID ("status_page")), icon);
+        gtk_image_set_from_icon_name (GTK_IMAGE (WID ("device_icon")), icon);
 
 	/* Connection */
 	button = GTK_SWITCH (WID ("switch_connection"));
@@ -1149,23 +1142,23 @@ update_properties (BluetoothSettingsWidget *self,
 
 	/* UUIDs */
 	if (uuids && g_strv_contains ((const char * const*) uuids, "OBEXObjectPush"))
-		gtk_widget_set_visible (WID ("send_button"), TRUE);
+		gtk_widget_set_visible (WID ("send_button_row"), TRUE);
 
 	/* Type */
 	adw_action_row_set_subtitle (ADW_ACTION_ROW (WID ("type_row")),
 				     bluetooth_type_to_string (type));
 	switch (type) {
 	case BLUETOOTH_TYPE_KEYBOARD:
-		gtk_widget_set_visible (WID ("keyboard_button"), TRUE);
+		gtk_widget_set_visible (WID ("keyboard_button_row"), TRUE);
 		break;
 	case BLUETOOTH_TYPE_MOUSE:
 	case BLUETOOTH_TYPE_TABLET:
-		gtk_widget_set_visible (WID ("mouse_button"), TRUE);
+		gtk_widget_set_visible (WID ("mouse_button_row"), TRUE);
 		break;
 	case BLUETOOTH_TYPE_HEADSET:
 	case BLUETOOTH_TYPE_HEADPHONES:
 	case BLUETOOTH_TYPE_OTHER_AUDIO:
-		gtk_widget_set_visible (WID ("sound_button"), TRUE);
+		gtk_widget_set_visible (WID ("sound_button_row"), TRUE);
 	default:
 		/* others? */
 		;
@@ -1188,28 +1181,28 @@ switch_panel (BluetoothSettingsWidget *self,
 }
 
 static void
-keyboard_callback (GtkButton        *button,
+keyboard_callback (AdwButtonRow            *row,
 		   BluetoothSettingsWidget *self)
 {
 	switch_panel (self, KEYBOARD_PREFS);
 }
 
 static void
-mouse_callback (GtkButton        *button,
+mouse_callback (AdwButtonRow            *row,
 		BluetoothSettingsWidget *self)
 {
 	switch_panel (self, MOUSE_PREFS);
 }
 
 static void
-sound_callback (GtkButton        *button,
-		BluetoothSettingsWidget *self)
+sound_callback (AdwButtonRow            *row,
+                BluetoothSettingsWidget *self)
 {
 	switch_panel (self, SOUND_PREFS);
 }
 
 static void
-send_callback (GtkButton               *button,
+send_callback (AdwButtonRow            *row,
 	       BluetoothSettingsWidget *self)
 {
 	g_autoptr(GError) error = NULL;
@@ -1227,7 +1220,7 @@ update_visibility (BluetoothSettingsWidget *self)
 
 	g_object_get (G_OBJECT (self->client), "default-adapter-name", &name, NULL);
 	if (name != NULL) {
-		g_autofree char *label = NULL;
+		g_autofree char *description = NULL;
 		g_autofree char *path = NULL;
 		g_autofree char *uri = NULL;
 
@@ -1237,10 +1230,11 @@ update_visibility (BluetoothSettingsWidget *self)
 		/* translators: first %s is the name of the computer, for example:
 		 * Visible as “Bastien Nocera’s Computer” followed by the
 		 * location of the Downloads folder.*/
-		label = g_strdup_printf (_("Visible as “%s” and available for Bluetooth file transfers. Transferred files are placed in the <a href=\"%s\">Downloads</a> folder."), name, uri);
-		adw_preferences_group_set_description (ADW_PREFERENCES_GROUP (self->explanation_group), label);
-	}
-	gtk_widget_set_visible (self->explanation_group, name != NULL);
+		description = g_strdup_printf (_("Visible as “%s” and available for Bluetooth file transfers. Transferred files are placed in the <a href=\"%s\">Downloads</a> folder."), name, uri);
+		adw_preferences_page_set_description (ADW_PREFERENCES_PAGE (self->page), description);
+	} else {
+                adw_preferences_page_set_description (ADW_PREFERENCES_PAGE (self->page), NULL);
+        }
 }
 
 static void
@@ -1290,41 +1284,43 @@ remove_selected_device (BluetoothSettingsWidget *self)
 }
 
 static void
-confirm_dialog_remove_cb (AdwMessageDialog *dialog,
-			    gchar     *response,
-			    gpointer   user_data)
+confirm_dialog_remove_cb (AdwAlertDialog *dialog,
+                          gchar     *response,
+                          gpointer   user_data)
 {
 	BluetoothSettingsWidget *self = user_data;
 
 	remove_selected_device (self);
-	gtk_widget_set_visible (GTK_WIDGET (self->properties_dialog), FALSE);
+        adw_dialog_force_close (self->properties_dialog);
 }
 
 static void
 show_confirm_dialog (BluetoothSettingsWidget *self,
 		     const char *name)
 {
-	GtkWidget *dialog;
+	AdwDialog *dialog;
 
-	dialog = adw_message_dialog_new (GTK_WINDOW (self->properties_dialog), NULL,
-					 _("If you remove the device, you will have to set it up again before next use."));
-	adw_message_dialog_format_heading (ADW_MESSAGE_DIALOG (dialog),
-					 _("Remove “%s” from the list of devices?"), name);
+	dialog = adw_alert_dialog_new (_("Forget Device?"), NULL);
 
-	adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (dialog),
-				      "cancel", _("_Cancel"),
-				      "remove", _("_Remove"),
-				      NULL);
-	adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dialog), "remove", ADW_RESPONSE_DESTRUCTIVE);
+        adw_alert_dialog_format_body (ADW_ALERT_DIALOG (dialog),
+                                      _("“%s” will be removed from your saved devices. "
+                                                 "You will have to set it up again to use it."), name);
 
-	g_signal_connect (dialog, "response::remove", G_CALLBACK (confirm_dialog_remove_cb), self);
 
-	gtk_window_present (GTK_WINDOW (dialog));
+	adw_alert_dialog_add_responses (ADW_ALERT_DIALOG (dialog),
+                                        "cancel", _("_Cancel"),
+				        "forget", _("_Forget"),
+				        NULL);
+	adw_alert_dialog_set_response_appearance (ADW_ALERT_DIALOG (dialog), "forget", ADW_RESPONSE_DESTRUCTIVE);
+
+	g_signal_connect (dialog, "response::forget", G_CALLBACK (confirm_dialog_remove_cb), self);
+
+        adw_dialog_present (dialog, GTK_WIDGET (self));
 }
 
 static void
-delete_clicked (GtkButton               *button,
-		BluetoothSettingsWidget *self)
+delete_callback (AdwButtonRow              *row,
+		 BluetoothSettingsWidget   *self)
 {
 	show_confirm_dialog (self, self->selected_name);
 }
@@ -1419,8 +1415,7 @@ static void
 activate_row (BluetoothSettingsWidget *self,
               GtkListBoxRow    *row)
 {
-	GtkWindow *w;
-	GtkWidget *toplevel;
+	AdwDialog *w;
 	g_autoptr(BluetoothDevice) device = NULL;
 	gboolean paired, trusted, is_setup;
 
@@ -1432,13 +1427,15 @@ activate_row (BluetoothSettingsWidget *self,
 	is_setup = paired || trusted;
 
 	if (is_setup) {
+		GtkWidget *page;
+
 		update_properties (self, device);
 
+		page = WID ("preferences_page");
+		adw_preferences_page_scroll_to_top (ADW_PREFERENCES_PAGE (page));
+
 		w = self->properties_dialog;
-		toplevel = GTK_WIDGET (gtk_widget_get_native (GTK_WIDGET (self)));
-		gtk_window_set_transient_for (w, GTK_WINDOW (toplevel));
-		gtk_window_set_modal (w, TRUE);
-		gtk_window_present (w);
+		adw_dialog_present (w, GTK_WIDGET (self));
 	} else {
 		start_pairing (self, row);
 	}
@@ -1450,12 +1447,12 @@ add_device_section (BluetoothSettingsWidget *self)
 	/* Discoverable spinner */
 	self->device_spinner = WID ("device_spinner");
 	g_object_bind_property (G_OBJECT (self->client), "default-adapter-setup-mode",
-				G_OBJECT (self->device_spinner), "spinning",
+				G_OBJECT (self->device_spinner), "visible",
 				G_BINDING_SYNC_CREATE);
 
 	/* Discoverable label placeholder, the real name is set in update_visibility().
 	 * If you ever see this string during normal use, please file a bug. */
-	self->explanation_group = WID ("explanation_group");
+	self->page = WID ("page");
 	update_visibility (self);
 
 	self->device_list = WID ("device_list");
@@ -1464,8 +1461,6 @@ add_device_section (BluetoothSettingsWidget *self)
 				    (GtkListBoxSortFunc)device_sort_func, NULL, NULL);
 	g_signal_connect_swapped (self->device_list, "row-activated",
 				  G_CALLBACK (activate_row), self);
-
-	self->device_stack = WID ("device_stack");
 }
 
 static void
@@ -1534,10 +1529,6 @@ device_added_cb (BluetoothClient *client,
 	gtk_list_box_append (GTK_LIST_BOX (self->device_list), row);
 	gtk_size_group_add_widget (self->row_sizegroup, row);
 
-	gtk_stack_set_transition_type (GTK_STACK (self->device_stack),
-				       GTK_STACK_TRANSITION_TYPE_SLIDE_DOWN);
-	gtk_stack_set_visible_child_name (GTK_STACK (self->device_stack), DEVICES_PAGE);
-
 	g_signal_connect_object (G_OBJECT (device), "notify",
 				 G_CALLBACK (device_changed_cb), self, 0);
 }
@@ -1572,15 +1563,9 @@ device_removed_cb (BluetoothClient *client,
 		}
 	}
 
-	if (found) {
-		if (gtk_widget_get_first_child (self->device_list) == NULL) {
-			gtk_stack_set_transition_type (GTK_STACK (self->device_stack),
-						       GTK_STACK_TRANSITION_TYPE_NONE);
-			gtk_stack_set_visible_child_name (GTK_STACK (self->device_stack), FILLER_PAGE);
-		}
-	} else {
-		g_debug ("Didn't find a row to remove for tree path %s", object_path);
-	}
+        if (!found) {
+             g_debug ("Didn't find a row to remove for tree path %s", object_path);
+        }
 }
 
 static void
@@ -1602,17 +1587,17 @@ devices_coldplug (BluetoothSettingsWidget *self)
 static void
 setup_properties_dialog (BluetoothSettingsWidget *self)
 {
-	self->properties_dialog = GTK_WINDOW (WID ("properties_dialog"));
+	self->properties_dialog = ADW_DIALOG (WID ("properties_dialog"));
 
-	g_signal_connect (G_OBJECT (WID ("delete_button")), "clicked",
-			  G_CALLBACK (delete_clicked), self);
-	g_signal_connect (G_OBJECT (WID ("mouse_button")), "clicked",
+	g_signal_connect (G_OBJECT (WID ("delete_button_row")), "activated",
+			  G_CALLBACK (delete_callback), self);
+	g_signal_connect (G_OBJECT (WID ("mouse_button_row")), "activated",
 			  G_CALLBACK (mouse_callback), self);
-	g_signal_connect (G_OBJECT (WID ("keyboard_button")), "clicked",
+	g_signal_connect (G_OBJECT (WID ("keyboard_button_row")), "activated",
 			  G_CALLBACK (keyboard_callback), self);
-	g_signal_connect (G_OBJECT (WID ("sound_button")), "clicked",
+	g_signal_connect (G_OBJECT (WID ("sound_button_row")), "activated",
 			  G_CALLBACK (sound_callback), self);
-	g_signal_connect (G_OBJECT (WID ("send_button")), "clicked",
+	g_signal_connect (G_OBJECT (WID ("send_button_row")), "activated",
 			  G_CALLBACK (send_callback), self);
 	g_signal_connect (G_OBJECT (WID ("switch_connection")), "state-set",
 			  G_CALLBACK (switch_connected_state_set), self);
@@ -1772,8 +1757,8 @@ bluetooth_settings_widget_finalize (GObject *object)
 	BluetoothSettingsWidget *self = BLUETOOTH_SETTINGS_WIDGET(object);
 
 	g_clear_object (&self->agent);
-	g_clear_pointer (&self->properties_dialog, gtk_window_destroy);
-	g_clear_pointer (&self->pairing_dialog, gtk_window_destroy);
+	g_clear_pointer (&self->properties_dialog, adw_dialog_force_close);
+	g_clear_pointer (&self->pairing_dialog, adw_dialog_force_close);
 	g_clear_object (&self->session_proxy);
 
 	obex_agent_down ();
